@@ -34,7 +34,7 @@ urllib3.disable_warnings()
 
 
 class HtmlProoferPlugin(BasePlugin):
-    files: Files = None
+    files: Files
 
     config_scheme = (
         ("enabled", config_options.Type(bool, default=True)),
@@ -63,10 +63,10 @@ class HtmlProoferPlugin(BasePlugin):
 
         # Optimization: only parse links and headings
         # li, sup are used for footnotes
-        strainer = SoupStrainer(('a', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'li', 'sup'))
+        strainer = SoupStrainer(('a', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'li', 'sup', 'img'))
 
         content = output_content if self.config['validate_rendered_template'] else page.content
-        soup = BeautifulSoup(content, 'lxml', parse_only=strainer)
+        soup = BeautifulSoup(content, 'html.parser', parse_only=strainer)
 
         all_element_ids = set(tag['id'] for tag in soup.select('[id]'))
         all_element_ids.add('')  # Empty anchor is commonly used, but not real
@@ -87,7 +87,7 @@ class HtmlProoferPlugin(BasePlugin):
     @lru_cache(maxsize=1000)
     def get_external_url(self, url: str) -> int:
         try:
-            response = self._session.head(url, timeout=URL_TIMEOUT)
+            response = self._session.get(url, timeout=URL_TIMEOUT)
             return response.status_code
         except requests.exceptions.Timeout:
             return 504
@@ -131,7 +131,7 @@ class HtmlProoferPlugin(BasePlugin):
         # Handle relative links by concatenating the source dir with the destination path
         search = os.path.normpath(str(pathlib.Path(src_path).parent / pathlib.Path(url)))
         for file in files.src_paths.values():  # type: File
-            if file.url == search:
+            if file.url == search and file.page:
                 return file.page.markdown
 
         print(f"Warning: Unable to locate Markdown source file for: {url}", file=sys.stderr)
